@@ -9,9 +9,11 @@ class Supersql(object):
         self._dsn = dsn
         self._vendor = None
         self._connexion = None
+        self._pooled = False
 
-    async def connect(self):
-        vendor, connector = await Connexer(self._dsn)
+    async def connect(self, pooled = False):
+        self._pooled = pooled
+        vendor, connector = await Connexer(self._dsn, self._pooled)
         self._connexion = connector
         self._vendor = vendor
 
